/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.Actions.HandleButtonEvents.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "handlebuttoneventsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class HandleButtonEventsAdaptor
 */

HandleButtonEventsAdaptor::HandleButtonEventsAdaptor(PowerDevil::BundledActions::HandleButtonEvents *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

HandleButtonEventsAdaptor::~HandleButtonEventsAdaptor()
{
    // destructor
}

int HandleButtonEventsAdaptor::lidAction()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.HandleButtonEvents.lidAction
    return parent()->lidAction();
}

bool HandleButtonEventsAdaptor::triggersLidAction()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.HandleButtonEvents.triggersLidAction
    return parent()->triggersLidAction();
}


#include "moc_handlebuttoneventsadaptor.cpp"
