/****************************************************************************
** Meta object code from reading C++ file 'batterycontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../powerdevil-6.7.4/daemon/controllers/batterycontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'batterycontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17BatteryControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto BatteryController::qt_create_metaobjectdata<qt_meta_tag_ZN17BatteryControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BatteryController",
        "acAdapterStateChanged",
        "",
        "BatteryController::AcAdapterState",
        "newState",
        "batteryRemainingTimeChanged",
        "time",
        "smoothedBatteryRemainingTimeChanged",
        "onPropertiesChanged",
        "ifaceName",
        "QVariantMap",
        "changedProps",
        "invalidatedProps",
        "updateDeviceProps",
        "slotDeviceAdded",
        "QDBusObjectPath",
        "path",
        "slotDeviceRemoved",
        "AcAdapterState",
        "UnknownAcAdapterState",
        "Plugged",
        "Unplugged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'acAdapterStateChanged'
        QtMocHelpers::SignalData<void(BatteryController::AcAdapterState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'batteryRemainingTimeChanged'
        QtMocHelpers::SignalData<void(qulonglong)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 6 },
        }}),
        // Signal 'smoothedBatteryRemainingTimeChanged'
        QtMocHelpers::SignalData<void(qulonglong)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 6 },
        }}),
        // Slot 'onPropertiesChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 }, { QMetaType::QStringList, 12 },
        }}),
        // Slot 'updateDeviceProps'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeviceAdded'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotDeviceRemoved'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AcAdapterState'
        QtMocHelpers::EnumData<enum AcAdapterState>(18, 18, QMC::EnumFlags{}).add({
            {   19, AcAdapterState::UnknownAcAdapterState },
            {   20, AcAdapterState::Plugged },
            {   21, AcAdapterState::Unplugged },
        }),
    };
    return QtMocHelpers::metaObjectData<BatteryController, qt_meta_tag_ZN17BatteryControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BatteryController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17BatteryControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17BatteryControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17BatteryControllerE_t>.metaTypes,
    nullptr
} };

void BatteryController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BatteryController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->acAdapterStateChanged((*reinterpret_cast<std::add_pointer_t<BatteryController::AcAdapterState>>(_a[1]))); break;
        case 1: _t->batteryRemainingTimeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 2: _t->smoothedBatteryRemainingTimeChanged((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 3: _t->onPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 4: _t->updateDeviceProps(); break;
        case 5: _t->slotDeviceAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 6: _t->slotDeviceRemoved((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BatteryController::*)(BatteryController::AcAdapterState )>(_a, &BatteryController::acAdapterStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BatteryController::*)(qulonglong )>(_a, &BatteryController::batteryRemainingTimeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BatteryController::*)(qulonglong )>(_a, &BatteryController::smoothedBatteryRemainingTimeChanged, 2))
            return;
    }
}

const QMetaObject *BatteryController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BatteryController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17BatteryControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BatteryController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void BatteryController::acAdapterStateChanged(BatteryController::AcAdapterState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BatteryController::batteryRemainingTimeChanged(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BatteryController::smoothedBatteryRemainingTimeChanged(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
